@@ -1,4 +1,5 @@
 from sdkite.http.adapter import HTTPAdapter, HTTPAdapterSpec
+from sdkite.http.auth import BasicAuth, NoAuth
 from sdkite.http.model import (
     HTTPBodyEncoding,
     HTTPHeaderDict,
@@ -7,8 +8,13 @@ from sdkite.http.model import (
 )
 
 __all__ = (
+    # sdkite.http.adapter
     "HTTPAdapter",
     "HTTPAdapterSpec",
+    # sdkite.http.auth
+    "BasicAuth",
+    "NoAuth",
+    # sdkite.http.model
     "HTTPBodyEncoding",
     "HTTPHeaderDict",
     "HTTPRequest",
